package model

import (
	"errors"
	"time"
)

type Config struct {
	ApiURL                 string `yaml:"apiUrl"`
	ApiKey                 string `yaml:"apiKey"`
	Subject                string `yaml:"subject"`
	Sender                 string `yaml:"sender"`
	PathToTemplateData     string `yaml:"pathToTemplateData"`
	PathToReminderTemplate string `yaml:"pathToReminderTemplate"`
	PathToToClientTemplate string `yaml:"pathToToClientTemplate"`
	To                     string `yaml:"to"`
}

func (c *Config) Validate() error {
	if c.ApiURL == "" {
		return errors.New("ApiURL dont be nil")
	}
	if c.ApiKey == "" {
		return errors.New("ApiKey dont be nil")
	}
	if c.Subject == "" {
		return errors.New("Subject dont be nil")
	}
	if c.Sender == "" {
		return errors.New("Sender dont be nil")
	}
	if c.PathToTemplateData == "" {
		return errors.New("PathToTemplateData dont be nil")
	}
	if c.PathToReminderTemplate == "" {
		return errors.New("PathToReminderTemplate dont be nil")
	}
	if c.PathToToClientTemplate == "" {
		return errors.New("PathToToClientTemplate dont be nil")
	}
	if c.To == "" {
		return errors.New("To dont be nil")
	}
	return nil
}

type ResultInfo struct {
	When     string `json:"when"`      // before|after|email
	Theme    string `json:"theme"`     // тема письма
	Reply    string `json:"reply"`     // email для ответов, указывается в создании письма
	ReplName string `json:"repl_name"` // имя отправителя
}

type ResultContent struct {
	Text      string            `json:"text"`
	Name      string            `json:"name"`
	Email     string            `json:"email"`
	Phone     string            `json:"phone"`
	Address   string            `json:"address"`
	Telegram  string            `json:"telegram"`
	Wechat    string            `json:"wechat"`
	Viber     string            `json:"viber"`
	Vk        string            `json:"vk"`
	Skype     string            `json:"skype"`
	Whatsup   string            `json:"whatsup"`
	Messenger string            `json:"messenger"`
	Custom    map[string]string `json:"customs"`
	Start     bool              `json:"start"`
}

type ResultAnswer struct {
	Content    string
	CreatedAt  time.Time
	QuestionID uint64
	AnswerID   uint64
}

type ImageContent struct {
	Description string
	Image       string
}
